
#include "i2chw.h"

/*---------------------------------------------------------------------------*/
void i2c_init(void){

  P3SEL = 0x0A;         // select module function for the used I2C pins
  P3DIR &= ~0x0A;       // select ports for I2C function 
  
  // Recommended initialisation steps of I2C module as shown in User Guide:
  U0CTL |= I2C+SYNC;     // (1) Select I2C mode with SWRST=1
  U0CTL &= ~I2CEN;       // (2) disable the I2C module
                         // (3) Configure the I2C module with I2CEN=0 :
  
                              // U0CTL default settings:
                              // 7-bit addressing, no DMA, no feedback
  I2CTCTL = I2CTRX+I2CSSEL_2; // byte mode, repeat mode, clock source = SMCLK,
                              // transmitt mode
  //I2COA = 0x01A5;           // own address. for slave mode
  
  I2CPSC = 0x02;                  // I2C clock = clock source/I2CPSC
                                  // fr 8MHz Quarz / (3+1) ==> 2MHz
  I2CSCLH = 0x08;                 // SCL high period = (8+2)*I2C clock
                                  // 1/2MHz ==> 0.5Sec * 10 => 5Sec 
  I2CSCLL = 0x08;                 // SCL low period  => wie I2CSLH
                                  // SCL Low, 5Sec + SCL High, 5Sec = 10Sec
                                  // ==> 1/10Sec = 100kHz I2C Clock
                                  
  //I2CIFG = 0;
  
 
}/* i2c_init */

/*************************************************************************	
  Issues a start condition and sends address and transfer direction.
  return 0 = device accessible, 1= failed to access device
*************************************************************************/
unsigned char i2c_start(unsigned char address) {
         
    I2CNDAT = 0x01;       // I2C Data count (one byte)
    I2CSA = address;      //set I2C Slave Address
    U0CTL |= I2CEN;       // (4) set I2CEN via software
    
    //U0CTL |= MST;    //set I2C to Master Mode
                                  
    //I2CTCTL |= I2CTRX+I2CSTT+I2CSTP;  // I2CTRX=1 => Transmit Mode (R/W bit = 0)
                                      // start and stop condition generation
                                      // => I2C communication is started
    return 0;
	
}/* i2c_start */

unsigned char i2c_rep_start(unsigned char address) {
         
    return i2c_start( address );

}/* i2c_rep_start */


/*************************************************************************
 Terminates the data transfer and releases the I2C bus
*************************************************************************/
void i2c_stop(void) {
  

}/* i2c_stop */



/*************************************************************************
  Send one byte to I2C device
  
  Input:    byte to be transfered
  Return:   0 write successful 
            1 write failed
*************************************************************************/
unsigned char i2c_write( unsigned char data ) {	

}/* i2c_write */



//*****************************************************************************
// Read one byte from the I2C device, request more data from device 
// Return:  byte read from I2C device
//*****************************************************************************
unsigned char i2c_readAck(void) {
         
    ///while (I2CBUSY & I2CDCTL);  // wait for i2C ready
    i2c_readInit();             // set to readMode                
    I2CTCTL |= I2CSTT;          // I2CRM =0; Receive, ST
                                // => I2C communication is started                           
    while((I2CIFG & RXRDYIFG) != RXRDYIFG); // wait for Receive Data Ready 
    return I2CDRB; 
}
//*****************************************************************************
// Read one byte from the I2C device, read is followed by a stop condition 
// Return:  byte read from I2C device
//*****************************************************************************
unsigned char i2c_readNak(void) {
                 
    while (I2CBUSY & I2CDCTL);  // wait for i2C ready
    i2c_readInit();             // set to readMode                
    I2CTCTL |= I2CSTT + I2CSTP; // I2CRM =0; Receive, ST, SP (clears MST)
                                // => I2C communication is started                           
    while((I2CIFG & RXRDYIFG) != RXRDYIFG); // wait for Receive Data Ready 
    return I2CDRB;  
}

//*****************************************************************************
// Set I2C to Master write Mode 
//*****************************************************************************
static void i2c_writeInit(void){
  // Initialization of the I2C Module for Write operation.
  U0CTL |= MST;           // define Master Mode
  I2CTCTL |= I2CTRX;      // I2CTRX=1 => Transmit Mode (R/W bit = 0)
  I2CIFG &= ~TXRDYIFG;    // clear Transmit Data ready
  //I2CIE = TXRDYIE;      // enable Transmit ready interrupt
}

//*****************************************************************************
// Set I2C to Master read Mode 
//*****************************************************************************
static void i2c_readInit(void){  
  // Initialization of the I2C Module for Read operation.
  U0CTL |= MST;           // define Master Mode
  I2CTCTL &= ~I2CTRX;     // I2CTRX=0 => Receive Mode (R/W bit = 1)
  I2CIFG &= ~TXRDYIFG;    // clear Receive Data ready
  //I2CIE = RXRDYIE;      // enable Receive ready interrupt
}
